import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.delete_file_response import DeleteFileResponse  # noqa: E501
from timestep.apis.openai.models.list_files_response import ListFilesResponse  # noqa: E501
from timestep.apis.openai.models.open_ai_file import OpenAIFile  # noqa: E501
from timestep.apis.openai import util


def create_file(file, purpose):  # noqa: E501
    """Upload a file that can be used across various endpoints. Individual files can be up to 512 MB, and the size of all files uploaded by one organization can be up to 100 GB.  The Assistants API supports files up to 2 million tokens and of specific file types. See the [Assistants Tools guide](/docs/assistants/tools) for details.  The Fine-tuning API only supports &#x60;.jsonl&#x60; files. The input also has certain required formats for fine-tuning [chat](/docs/api-reference/fine-tuning/chat-input) or [completions](/docs/api-reference/fine-tuning/completions-input) models.  The Batch API only supports &#x60;.jsonl&#x60; files up to 100 MB in size. The input also has a specific required [format](/docs/api-reference/batch/request-input).  Please [contact us](https://help.openai.com/) if you need to increase these storage limits. 

     # noqa: E501

    :param file: The File object (not file name) to be uploaded. 
    :type file: str
    :param purpose: The intended purpose of the uploaded file.  Use \\\&quot;assistants\\\&quot; for [Assistants](/docs/api-reference/assistants) and [Message](/docs/api-reference/messages) files, \\\&quot;vision\\\&quot; for Assistants image file inputs, \\\&quot;batch\\\&quot; for [Batch API](/docs/guides/batch), and \\\&quot;fine-tune\\\&quot; for [Fine-tuning](/docs/api-reference/fine-tuning). 
    :type purpose: str

    :rtype: Union[OpenAIFile, Tuple[OpenAIFile, int], Tuple[OpenAIFile, int, Dict[str, str]]
    """
    return 'do some magic!'


def delete_file(file_id):  # noqa: E501
    """Delete a file.

     # noqa: E501

    :param file_id: The ID of the file to use for this request.
    :type file_id: str

    :rtype: Union[DeleteFileResponse, Tuple[DeleteFileResponse, int], Tuple[DeleteFileResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def download_file(file_id):  # noqa: E501
    """Returns the contents of the specified file.

     # noqa: E501

    :param file_id: The ID of the file to use for this request.
    :type file_id: str

    :rtype: Union[str, Tuple[str, int], Tuple[str, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_files(purpose=None):  # noqa: E501
    """Returns a list of files that belong to the user&#39;s organization.

     # noqa: E501

    :param purpose: Only return files with the given purpose.
    :type purpose: str

    :rtype: Union[ListFilesResponse, Tuple[ListFilesResponse, int], Tuple[ListFilesResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def retrieve_file(file_id):  # noqa: E501
    """Returns information about a specific file.

     # noqa: E501

    :param file_id: The ID of the file to use for this request.
    :type file_id: str

    :rtype: Union[OpenAIFile, Tuple[OpenAIFile, int], Tuple[OpenAIFile, int, Dict[str, str]]
    """
    return 'do some magic!'



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.assistant_object import AssistantObject  # noqa: E501
from timestep.apis.openai.models.create_assistant_request import CreateAssistantRequest  # noqa: E501
from timestep.apis.openai.models.create_message_request import CreateMessageRequest  # noqa: E501
from timestep.apis.openai.models.create_run_request import CreateRunRequest  # noqa: E501
from timestep.apis.openai.models.create_thread_and_run_request import CreateThreadAndRunRequest  # noqa: E501
from timestep.apis.openai.models.create_thread_request import CreateThreadRequest  # noqa: E501
from timestep.apis.openai.models.delete_assistant_response import DeleteAssistantResponse  # noqa: E501
from timestep.apis.openai.models.delete_message_response import DeleteMessageResponse  # noqa: E501
from timestep.apis.openai.models.delete_thread_response import DeleteThreadResponse  # noqa: E501
from timestep.apis.openai.models.list_assistants_response import ListAssistantsResponse  # noqa: E501
from timestep.apis.openai.models.list_messages_response import ListMessagesResponse  # noqa: E501
from timestep.apis.openai.models.list_run_steps_response import ListRunStepsResponse  # noqa: E501
from timestep.apis.openai.models.list_runs_response import ListRunsResponse  # noqa: E501
from timestep.apis.openai.models.message_object import MessageObject  # noqa: E501
from timestep.apis.openai.models.modify_assistant_request import ModifyAssistantRequest  # noqa: E501
from timestep.apis.openai.models.modify_message_request import ModifyMessageRequest  # noqa: E501
from timestep.apis.openai.models.modify_run_request import ModifyRunRequest  # noqa: E501
from timestep.apis.openai.models.modify_thread_request import ModifyThreadRequest  # noqa: E501
from timestep.apis.openai.models.run_object import RunObject  # noqa: E501
from timestep.apis.openai.models.run_step_object import RunStepObject  # noqa: E501
from timestep.apis.openai.models.submit_tool_outputs_run_request import SubmitToolOutputsRunRequest  # noqa: E501
from timestep.apis.openai.models.thread_object import ThreadObject  # noqa: E501
from timestep.apis.openai import util


def cancel_run(thread_id, run_id):  # noqa: E501
    """Cancels a run that is &#x60;in_progress&#x60;.

     # noqa: E501

    :param thread_id: The ID of the thread to which this run belongs.
    :type thread_id: str
    :param run_id: The ID of the run to cancel.
    :type run_id: str

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    return 'do some magic!'


def create_assistant(create_assistant_request):  # noqa: E501
    """Create an assistant with a model and instructions.

     # noqa: E501

    :param create_assistant_request: 
    :type create_assistant_request: dict | bytes

    :rtype: Union[AssistantObject, Tuple[AssistantObject, int], Tuple[AssistantObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_assistant_request = CreateAssistantRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def create_message(thread_id, create_message_request):  # noqa: E501
    """Create a message.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) to create a message for.
    :type thread_id: str
    :param create_message_request: 
    :type create_message_request: dict | bytes

    :rtype: Union[MessageObject, Tuple[MessageObject, int], Tuple[MessageObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_message_request = CreateMessageRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def create_run(thread_id, create_run_request):  # noqa: E501
    """Create a run.

     # noqa: E501

    :param thread_id: The ID of the thread to run.
    :type thread_id: str
    :param create_run_request: 
    :type create_run_request: dict | bytes

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_run_request = CreateRunRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def create_thread(create_thread_request=None):  # noqa: E501
    """Create a thread.

     # noqa: E501

    :param create_thread_request: 
    :type create_thread_request: dict | bytes

    :rtype: Union[ThreadObject, Tuple[ThreadObject, int], Tuple[ThreadObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_thread_request = CreateThreadRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def create_thread_and_run(create_thread_and_run_request):  # noqa: E501
    """Create a thread and run it in one request.

     # noqa: E501

    :param create_thread_and_run_request: 
    :type create_thread_and_run_request: dict | bytes

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_thread_and_run_request = CreateThreadAndRunRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def delete_assistant(assistant_id):  # noqa: E501
    """Delete an assistant.

     # noqa: E501

    :param assistant_id: The ID of the assistant to delete.
    :type assistant_id: str

    :rtype: Union[DeleteAssistantResponse, Tuple[DeleteAssistantResponse, int], Tuple[DeleteAssistantResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def delete_message(thread_id, message_id):  # noqa: E501
    """Deletes a message.

     # noqa: E501

    :param thread_id: The ID of the thread to which this message belongs.
    :type thread_id: str
    :param message_id: The ID of the message to delete.
    :type message_id: str

    :rtype: Union[DeleteMessageResponse, Tuple[DeleteMessageResponse, int], Tuple[DeleteMessageResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def delete_thread(thread_id):  # noqa: E501
    """Delete a thread.

     # noqa: E501

    :param thread_id: The ID of the thread to delete.
    :type thread_id: str

    :rtype: Union[DeleteThreadResponse, Tuple[DeleteThreadResponse, int], Tuple[DeleteThreadResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def get_assistant(assistant_id):  # noqa: E501
    """Retrieves an assistant.

     # noqa: E501

    :param assistant_id: The ID of the assistant to retrieve.
    :type assistant_id: str

    :rtype: Union[AssistantObject, Tuple[AssistantObject, int], Tuple[AssistantObject, int, Dict[str, str]]
    """
    return 'do some magic!'


def get_message(thread_id, message_id):  # noqa: E501
    """Retrieve a message.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) to which this message belongs.
    :type thread_id: str
    :param message_id: The ID of the message to retrieve.
    :type message_id: str

    :rtype: Union[MessageObject, Tuple[MessageObject, int], Tuple[MessageObject, int, Dict[str, str]]
    """
    return 'do some magic!'


def get_run(thread_id, run_id):  # noqa: E501
    """Retrieves a run.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) that was run.
    :type thread_id: str
    :param run_id: The ID of the run to retrieve.
    :type run_id: str

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    return 'do some magic!'


def get_run_step(thread_id, run_id, step_id):  # noqa: E501
    """Retrieves a run step.

     # noqa: E501

    :param thread_id: The ID of the thread to which the run and run step belongs.
    :type thread_id: str
    :param run_id: The ID of the run to which the run step belongs.
    :type run_id: str
    :param step_id: The ID of the run step to retrieve.
    :type step_id: str

    :rtype: Union[RunStepObject, Tuple[RunStepObject, int], Tuple[RunStepObject, int, Dict[str, str]]
    """
    return 'do some magic!'


def get_thread(thread_id):  # noqa: E501
    """Retrieves a thread.

     # noqa: E501

    :param thread_id: The ID of the thread to retrieve.
    :type thread_id: str

    :rtype: Union[ThreadObject, Tuple[ThreadObject, int], Tuple[ThreadObject, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_assistants(limit=None, order=None, after=None, before=None):  # noqa: E501
    """Returns a list of assistants.

     # noqa: E501

    :param limit: A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20. 
    :type limit: int
    :param order: Sort order by the &#x60;created_at&#x60; timestamp of the objects. &#x60;asc&#x60; for ascending order and &#x60;desc&#x60; for descending order. 
    :type order: str
    :param after: A cursor for use in pagination. &#x60;after&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after&#x3D;obj_foo in order to fetch the next page of the list. 
    :type after: str
    :param before: A cursor for use in pagination. &#x60;before&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include before&#x3D;obj_foo in order to fetch the previous page of the list. 
    :type before: str

    :rtype: Union[ListAssistantsResponse, Tuple[ListAssistantsResponse, int], Tuple[ListAssistantsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_messages(thread_id, limit=None, order=None, after=None, before=None, run_id=None):  # noqa: E501
    """Returns a list of messages for a given thread.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) the messages belong to.
    :type thread_id: str
    :param limit: A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20. 
    :type limit: int
    :param order: Sort order by the &#x60;created_at&#x60; timestamp of the objects. &#x60;asc&#x60; for ascending order and &#x60;desc&#x60; for descending order. 
    :type order: str
    :param after: A cursor for use in pagination. &#x60;after&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after&#x3D;obj_foo in order to fetch the next page of the list. 
    :type after: str
    :param before: A cursor for use in pagination. &#x60;before&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include before&#x3D;obj_foo in order to fetch the previous page of the list. 
    :type before: str
    :param run_id: Filter messages by the run ID that generated them. 
    :type run_id: str

    :rtype: Union[ListMessagesResponse, Tuple[ListMessagesResponse, int], Tuple[ListMessagesResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_run_steps(thread_id, run_id, limit=None, order=None, after=None, before=None):  # noqa: E501
    """Returns a list of run steps belonging to a run.

     # noqa: E501

    :param thread_id: The ID of the thread the run and run steps belong to.
    :type thread_id: str
    :param run_id: The ID of the run the run steps belong to.
    :type run_id: str
    :param limit: A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20. 
    :type limit: int
    :param order: Sort order by the &#x60;created_at&#x60; timestamp of the objects. &#x60;asc&#x60; for ascending order and &#x60;desc&#x60; for descending order. 
    :type order: str
    :param after: A cursor for use in pagination. &#x60;after&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after&#x3D;obj_foo in order to fetch the next page of the list. 
    :type after: str
    :param before: A cursor for use in pagination. &#x60;before&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include before&#x3D;obj_foo in order to fetch the previous page of the list. 
    :type before: str

    :rtype: Union[ListRunStepsResponse, Tuple[ListRunStepsResponse, int], Tuple[ListRunStepsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_runs(thread_id, limit=None, order=None, after=None, before=None):  # noqa: E501
    """Returns a list of runs belonging to a thread.

     # noqa: E501

    :param thread_id: The ID of the thread the run belongs to.
    :type thread_id: str
    :param limit: A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20. 
    :type limit: int
    :param order: Sort order by the &#x60;created_at&#x60; timestamp of the objects. &#x60;asc&#x60; for ascending order and &#x60;desc&#x60; for descending order. 
    :type order: str
    :param after: A cursor for use in pagination. &#x60;after&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after&#x3D;obj_foo in order to fetch the next page of the list. 
    :type after: str
    :param before: A cursor for use in pagination. &#x60;before&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include before&#x3D;obj_foo in order to fetch the previous page of the list. 
    :type before: str

    :rtype: Union[ListRunsResponse, Tuple[ListRunsResponse, int], Tuple[ListRunsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def modify_assistant(assistant_id, modify_assistant_request):  # noqa: E501
    """Modifies an assistant.

     # noqa: E501

    :param assistant_id: The ID of the assistant to modify.
    :type assistant_id: str
    :param modify_assistant_request: 
    :type modify_assistant_request: dict | bytes

    :rtype: Union[AssistantObject, Tuple[AssistantObject, int], Tuple[AssistantObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        modify_assistant_request = ModifyAssistantRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def modify_message(thread_id, message_id, modify_message_request):  # noqa: E501
    """Modifies a message.

     # noqa: E501

    :param thread_id: The ID of the thread to which this message belongs.
    :type thread_id: str
    :param message_id: The ID of the message to modify.
    :type message_id: str
    :param modify_message_request: 
    :type modify_message_request: dict | bytes

    :rtype: Union[MessageObject, Tuple[MessageObject, int], Tuple[MessageObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        modify_message_request = ModifyMessageRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def modify_run(thread_id, run_id, modify_run_request):  # noqa: E501
    """Modifies a run.

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) that was run.
    :type thread_id: str
    :param run_id: The ID of the run to modify.
    :type run_id: str
    :param modify_run_request: 
    :type modify_run_request: dict | bytes

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        modify_run_request = ModifyRunRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def modify_thread(thread_id, modify_thread_request):  # noqa: E501
    """Modifies a thread.

     # noqa: E501

    :param thread_id: The ID of the thread to modify. Only the &#x60;metadata&#x60; can be modified.
    :type thread_id: str
    :param modify_thread_request: 
    :type modify_thread_request: dict | bytes

    :rtype: Union[ThreadObject, Tuple[ThreadObject, int], Tuple[ThreadObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        modify_thread_request = ModifyThreadRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def submit_tool_ouputs_to_run(thread_id, run_id, submit_tool_outputs_run_request):  # noqa: E501
    """When a run has the &#x60;status: \&quot;requires_action\&quot;&#x60; and &#x60;required_action.type&#x60; is &#x60;submit_tool_outputs&#x60;, this endpoint can be used to submit the outputs from the tool calls once they&#39;re all completed. All outputs must be submitted in a single request. 

     # noqa: E501

    :param thread_id: The ID of the [thread](/docs/api-reference/threads) to which this run belongs.
    :type thread_id: str
    :param run_id: The ID of the run that requires the tool output submission.
    :type run_id: str
    :param submit_tool_outputs_run_request: 
    :type submit_tool_outputs_run_request: dict | bytes

    :rtype: Union[RunObject, Tuple[RunObject, int], Tuple[RunObject, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        submit_tool_outputs_run_request = SubmitToolOutputsRunRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'



import datetime

import typing
from timestep.apis.openai import typing_utils


def _deserialize(data, klass):
    """Deserializes dict, list, str into an object.

    :param data: dict, list or str.
    :param klass: class literal, or string of class name.

    :return: object.
    """
    if data is None:
        return None

    if klass in (int, float, str, bool, bytearray):
        return _deserialize_primitive(data, klass)
    elif klass == object:
        return _deserialize_object(data)
    elif klass == datetime.date:
        return deserialize_date(data)
    elif klass == datetime.datetime:
        return deserialize_datetime(data)
    elif typing_utils.is_generic(klass):
        if typing_utils.is_list(klass):
            return _deserialize_list(data, klass.__args__[0])
        if typing_utils.is_dict(klass):
            return _deserialize_dict(data, klass.__args__[1])
    else:
        return deserialize_model(data, klass)


def _deserialize_primitive(data, klass):
    """Deserializes to primitive type.

    :param data: data to deserialize.
    :param klass: class literal.

    :return: int, long, float, str, bool.
    :rtype: int | long | float | str | bool
    """
    try:
        value = klass(data)
    except UnicodeEncodeError:
        value = data
    except TypeError:
        value = data
    return value


def _deserialize_object(value):
    """Return an original value.

    :return: object.
    """
    return value


def deserialize_date(string):
    """Deserializes string to date.

    :param string: str.
    :type string: str
    :return: date.
    :rtype: date
    """
    if string is None:
      return None
    
    try:
        from dateutil.parser import parse
        return parse(string).date()
    except ImportError:
        return string


def deserialize_datetime(string):
    """Deserializes string to datetime.

    The string should be in iso8601 datetime format.

    :param string: str.
    :type string: str
    :return: datetime.
    :rtype: datetime
    """
    if string is None:
      return None
    
    try:
        from dateutil.parser import parse
        return parse(string)
    except ImportError:
        return string


def deserialize_model(data, klass):
    """Deserializes list or dict to model.

    :param data: dict, list.
    :type data: dict | list
    :param klass: class literal.
    :return: model object.
    """
    instance = klass()

    if not instance.openapi_types:
        return data

    for attr, attr_type in instance.openapi_types.items():
        if data is not None \
                and instance.attribute_map[attr] in data \
                and isinstance(data, (list, dict)):
            value = data[instance.attribute_map[attr]]
            setattr(instance, attr, _deserialize(value, attr_type))

    return instance


def _deserialize_list(data, boxed_type):
    """Deserializes a list and its elements.

    :param data: list to deserialize.
    :type data: list
    :param boxed_type: class literal.

    :return: deserialized list.
    :rtype: list
    """
    return [_deserialize(sub_data, boxed_type)
            for sub_data in data]


def _deserialize_dict(data, boxed_type):
    """Deserializes a dict and its elements.

    :param data: dict to deserialize.
    :type data: dict
    :param boxed_type: class literal.

    :return: deserialized dict.
    :rtype: dict
    """
    return {k: _deserialize(v, boxed_type)
            for k, v in data.items() }



import reflex as rx
from timestep.state import State

def sidebar_chat(chat: str) -> rx.Component:
    """A sidebar chat item.

    Args:
        chat: The chat item.
    """
    return  rx.drawer.close(rx.hstack(
        rx.button(
            chat, on_click=lambda: State.set_chat(chat), width="80%", variant="surface"
        ),
        rx.button(
            rx.icon(
                tag="trash",
                on_click=State.delete_chat,
                stroke_width=1,
            ),
            width="20%",
            variant="surface",
            color_scheme="red",
        ),
        width="100%",
    ))


def sidebar(trigger) -> rx.Component:
    """The sidebar component."""
    return rx.drawer.root(
        rx.drawer.trigger(trigger),
        rx.drawer.overlay(),
        rx.drawer.portal(
            rx.drawer.content(
                rx.vstack(
                    rx.heading("Chats", color=rx.color("mauve", 11)),
                    rx.divider(),
                    rx.foreach(State.chat_titles, lambda chat: sidebar_chat(chat)),
                    align_items="stretch",
                    width="100%",
                ),
                top="auto",
                right="auto",
                height="100%",
                width="20em",
                padding="2em",
                background_color=rx.color("mauve", 2),
                outline="none",
            )
        ),
        direction="left",
    )


def modal(trigger) -> rx.Component:
    """A modal to create a new chat."""
    return rx.dialog.root(
        rx.dialog.trigger(trigger),
        rx.dialog.content(
            rx.hstack(
                rx.input(
                    placeholder="Type something...",
                    on_blur=State.set_new_chat_name,
                    width=["15em", "20em", "30em", "30em", "30em", "30em"],
                ),
                rx.dialog.close(
                    rx.button(
                        "Create chat",
                        on_click=State.create_chat,
                    ),
                ),
                background_color=rx.color("mauve", 1),
                spacing="2",
                width="100%",
            ),
        ),
    )


def navbar():
    return rx.box(
        rx.hstack(
            rx.hstack(
                rx.avatar(fallback="RC", variant="solid"),
                rx.heading("Reflex Chat"),
                rx.desktop_only(
                    rx.badge(
                    State.current_chat,
                    rx.tooltip(rx.icon("info", size=14), content="The current selected chat."),
                    variant="soft"
                    )
                ),
                align_items="center",
            ),
            rx.hstack(
                modal(rx.button("+ New chat")),
                sidebar(
                    rx.button(
                        rx.icon(
                            tag="messages-square",
                            color=rx.color("mauve", 12),
                        ),
                        background_color=rx.color("mauve", 6),
                    )
                ),
                rx.desktop_only(
                    rx.button(
                        rx.icon(
                            tag="sliders-horizontal",
                            color=rx.color("mauve", 12),
                        ),
                        background_color=rx.color("mauve", 6),
                    )
                ),
                align_items="center",
            ),
            justify_content="space-between",
            align_items="center",
        ),
        backdrop_filter="auto",
        backdrop_blur="lg",
        padding="12px",
        border_bottom=f"1px solid {rx.color('mauve', 3)}",
        background_color=rx.color("mauve", 2),
        position="sticky",
        top="0",
        z_index="100",
        align_items="center",
    )



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.create_fine_tuning_job_request import CreateFineTuningJobRequest  # noqa: E501
from timestep.apis.openai.models.fine_tuning_job import FineTuningJob  # noqa: E501
from timestep.apis.openai.models.list_fine_tuning_job_checkpoints_response import ListFineTuningJobCheckpointsResponse  # noqa: E501
from timestep.apis.openai.models.list_fine_tuning_job_events_response import ListFineTuningJobEventsResponse  # noqa: E501
from timestep.apis.openai.models.list_paginated_fine_tuning_jobs_response import ListPaginatedFineTuningJobsResponse  # noqa: E501
from timestep.apis.openai import util


def cancel_fine_tuning_job(fine_tuning_job_id):  # noqa: E501
    """Immediately cancel a fine-tune job. 

     # noqa: E501

    :param fine_tuning_job_id: The ID of the fine-tuning job to cancel. 
    :type fine_tuning_job_id: str

    :rtype: Union[FineTuningJob, Tuple[FineTuningJob, int], Tuple[FineTuningJob, int, Dict[str, str]]
    """
    return 'do some magic!'


def create_fine_tuning_job(create_fine_tuning_job_request):  # noqa: E501
    """Creates a fine-tuning job which begins the process of creating a new model from a given dataset.  Response includes details of the enqueued job including job status and the name of the fine-tuned models once complete.  [Learn more about fine-tuning](/docs/guides/fine-tuning) 

     # noqa: E501

    :param create_fine_tuning_job_request: 
    :type create_fine_tuning_job_request: dict | bytes

    :rtype: Union[FineTuningJob, Tuple[FineTuningJob, int], Tuple[FineTuningJob, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_fine_tuning_job_request = CreateFineTuningJobRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def list_fine_tuning_events(fine_tuning_job_id, after=None, limit=None):  # noqa: E501
    """Get status updates for a fine-tuning job. 

     # noqa: E501

    :param fine_tuning_job_id: The ID of the fine-tuning job to get events for. 
    :type fine_tuning_job_id: str
    :param after: Identifier for the last event from the previous pagination request.
    :type after: str
    :param limit: Number of events to retrieve.
    :type limit: int

    :rtype: Union[ListFineTuningJobEventsResponse, Tuple[ListFineTuningJobEventsResponse, int], Tuple[ListFineTuningJobEventsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_fine_tuning_job_checkpoints(fine_tuning_job_id, after=None, limit=None):  # noqa: E501
    """List checkpoints for a fine-tuning job. 

     # noqa: E501

    :param fine_tuning_job_id: The ID of the fine-tuning job to get checkpoints for. 
    :type fine_tuning_job_id: str
    :param after: Identifier for the last checkpoint ID from the previous pagination request.
    :type after: str
    :param limit: Number of checkpoints to retrieve.
    :type limit: int

    :rtype: Union[ListFineTuningJobCheckpointsResponse, Tuple[ListFineTuningJobCheckpointsResponse, int], Tuple[ListFineTuningJobCheckpointsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_paginated_fine_tuning_jobs(after=None, limit=None):  # noqa: E501
    """List your organization&#39;s fine-tuning jobs 

     # noqa: E501

    :param after: Identifier for the last job from the previous pagination request.
    :type after: str
    :param limit: Number of fine-tuning jobs to retrieve.
    :type limit: int

    :rtype: Union[ListPaginatedFineTuningJobsResponse, Tuple[ListPaginatedFineTuningJobsResponse, int], Tuple[ListPaginatedFineTuningJobsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def retrieve_fine_tuning_job(fine_tuning_job_id):  # noqa: E501
    """Get info about a fine-tuning job.  [Learn more about fine-tuning](/docs/guides/fine-tuning) 

     # noqa: E501

    :param fine_tuning_job_id: The ID of the fine-tuning job. 
    :type fine_tuning_job_id: str

    :rtype: Union[FineTuningJob, Tuple[FineTuningJob, int], Tuple[FineTuningJob, int, Dict[str, str]]
    """
    return 'do some magic!'



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.create_embedding_request import CreateEmbeddingRequest  # noqa: E501
from timestep.apis.openai.models.create_embedding_response import CreateEmbeddingResponse  # noqa: E501
from timestep.apis.openai import util


def create_embedding(create_embedding_request):  # noqa: E501
    """Creates an embedding vector representing the input text.

     # noqa: E501

    :param create_embedding_request: 
    :type create_embedding_request: dict | bytes

    :rtype: Union[CreateEmbeddingResponse, Tuple[CreateEmbeddingResponse, int], Tuple[CreateEmbeddingResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_embedding_request = CreateEmbeddingRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.create_completion_request import CreateCompletionRequest  # noqa: E501
from timestep.apis.openai.models.create_completion_response import CreateCompletionResponse  # noqa: E501
from timestep.apis.openai import util


def create_completion(create_completion_request):  # noqa: E501
    """Creates a completion for the provided prompt and parameters.

     # noqa: E501

    :param create_completion_request: 
    :type create_completion_request: dict | bytes

    :rtype: Union[CreateCompletionResponse, Tuple[CreateCompletionResponse, int], Tuple[CreateCompletionResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_completion_request = CreateCompletionRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'



import logging

import connexion
from flask_testing import TestCase

from timestep.apis.openai.encoder import JSONEncoder


class BaseTestCase(TestCase):

    def create_app(self):
        logging.getLogger('connexion.operation').setLevel('ERROR')
        app = connexion.App(__name__, specification_dir='../openapi/')
        app.app.json_encoder = JSONEncoder
        app.add_api('openapi.yaml', pythonic_params=True)
        return app.app



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

import llama_cpp
from llama_cpp import Llama
from llama_cpp.server.types import (
    CreateCompletionRequest,
    CreateEmbeddingRequest,
    CreateChatCompletionRequest,
    ModelList,
    TokenizeInputRequest,
    TokenizeInputResponse,
    TokenizeInputCountResponse,
    DetokenizeInputRequest,
    DetokenizeInputResponse,
)
from llama_cpp.llama_chat_format import MoondreamChatHandler
from llama_cpp.server.errors import RouteErrorHandler

from timestep.apis.openai.models.create_chat_completion_request import CreateChatCompletionRequest  # noqa: E501
from timestep.apis.openai.models.create_chat_completion_response import CreateChatCompletionResponse  # noqa: E501
from timestep.apis.openai import util


def create_chat_completion(create_chat_completion_request):  # noqa: E501
    """Creates a model response for the given chat conversation.

     # noqa: E501

    :param create_chat_completion_request: 
    :type create_chat_completion_request: dict | bytes

    :rtype: Union[CreateChatCompletionResponse, Tuple[CreateChatCompletionResponse, int], Tuple[CreateChatCompletionResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_chat_completion_request = CreateChatCompletionRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'

# chat_handler = MoondreamChatHandler.from_pretrained(
#     repo_id="vikhyatk/moondream2",
#     filename="*mmproj*",
# )

# llm = Llama.from_pretrained(
#     repo_id="vikhyatk/moondream2",
#     filename="*text-model*",
#     chat_handler=chat_handler,
#     n_ctx=2048, # n_ctx should be increased to accommodate the image embedding
# )


# def createChatCompletion(body: CreateCompletionRequest) -> llama_cpp.ChatCompletion:
# # def createChatCompletion()
#     print('body: ', body)

#     # llm = Llama(
#     #     model_path="path/to/llama-2/llama-model.gguf",
#     #     chat_format="llama-2"
#     # )

#     # llm.create_chat_completion(
#     #     messages = [
#     #         {"role": "system", "content": "You are an assistant who perfectly describes images."},
#     #         {
#     #             "role": "user",
#     #             "content": "Describe this image in detail please."
#     #         }
#     #     ]
#     # )

#     # return {

#     # }

#     # chat_completion_chunk_stream = client.chat.completions.create(
#     #     messages=[
#     #         {"role": "system", "content": "You an AI assistant. Your top priority is responding to user questions with truthful answers."},
#     #         {"role": "user", "content": message},
#     #     ],
#     #     model="LLaMA_CPP",
#     #     stream=True,
#     #     stream_options={"include_usage": True}, # retrieving token usage for stream response
#     #     temperature=0,
#     # )

#     # collected_chunks = []
#     # collected_messages = []

#     # # iterate through the stream of events
#     # for chunk in chat_completion_chunk_stream:
#     #     chunk_time = time.time() - start_time  # calculate the time delay of the chunk
#     #     collected_chunks.append(chunk)  # save the event response
#     #     chunk_message = chunk.choices[0].delta.content  # extract the message
#     #     collected_messages.append(chunk_message)  # save the message
#     #     print(f"Message received {chunk_time:.2f} seconds after request: {chunk_message}")  # print the delay and text
#     #     print(f"choices: {chunk.choices}\nusage: {chunk.usage}")
#     #     print("****************")

#     # # print the time delay and text received
#     # print(f"Full response received {chunk_time:.2f} seconds after request")

#     # # clean None in collected_messages
#     # collected_messages = [m for m in collected_messages if m is not None]
#     # full_reply_content = ''.join(collected_messages)

#     # typer.echo(full_reply_content)

#     # chat_handler = MoondreamChatHandler.from_pretrained(
#     #     repo_id="vikhyatk/moondream2",
#     #     filename="*mmproj*",
#     # )

#     # llm = Llama.from_pretrained(
#     #     repo_id="vikhyatk/moondream2",
#     #     filename="*text-model*",
#     #     chat_handler=chat_handler,
#     #     n_ctx=2048, # n_ctx should be increased to accommodate the image embedding
#     # )

#     # response = llm.create_chat_completion(
#     #     messages = [
#     #         {
#     #             "role": "user",
#     #             "content": [
#     #                 {"type" : "text", "text": "What's in this image?"},
#     #                 {"type": "image_url", "image_url": {"url": "https://upload.wikimedia.org/wikipedia/commons/thumb/d/dd/Gfp-wisconsin-madison-the-nature-boardwalk.jpg/2560px-Gfp-wisconsin-madison-the-nature-boardwalk.jpg" } }

#     #             ]
#     #         }
#     #     ]
#     # )

#     print(response["choices"][0]["text"])

#     return response



import unittest

from flask import json

from timestep.apis.openai.models.delete_model_response import DeleteModelResponse  # noqa: E501
from timestep.apis.openai.models.list_models_response import ListModelsResponse  # noqa: E501
from timestep.apis.openai.models.model import Model  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestModelsController(BaseTestCase):
    """ModelsController integration test stubs"""

    def test_delete_model(self):
        """Test case for delete_model

        Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/models/{model}'.format(model='ft:gpt-3.5-turbo:acemeco:suffix:abc123'),
            method='DELETE',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_models(self):
        """Test case for list_models

        Lists the currently available models, and provides basic information about each one such as the owner and availability.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/models',
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_retrieve_model(self):
        """Test case for retrieve_model

        Retrieves a model instance, providing basic information about the model such as the owner and permissioning.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/models/{model}'.format(model='gpt-3.5-turbo'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import unittest

from flask import json

from timestep.apis.openai.models.assistant_object import AssistantObject  # noqa: E501
from timestep.apis.openai.models.create_assistant_request import CreateAssistantRequest  # noqa: E501
from timestep.apis.openai.models.create_message_request import CreateMessageRequest  # noqa: E501
from timestep.apis.openai.models.create_run_request import CreateRunRequest  # noqa: E501
from timestep.apis.openai.models.create_thread_and_run_request import CreateThreadAndRunRequest  # noqa: E501
from timestep.apis.openai.models.create_thread_request import CreateThreadRequest  # noqa: E501
from timestep.apis.openai.models.delete_assistant_response import DeleteAssistantResponse  # noqa: E501
from timestep.apis.openai.models.delete_message_response import DeleteMessageResponse  # noqa: E501
from timestep.apis.openai.models.delete_thread_response import DeleteThreadResponse  # noqa: E501
from timestep.apis.openai.models.list_assistants_response import ListAssistantsResponse  # noqa: E501
from timestep.apis.openai.models.list_messages_response import ListMessagesResponse  # noqa: E501
from timestep.apis.openai.models.list_run_steps_response import ListRunStepsResponse  # noqa: E501
from timestep.apis.openai.models.list_runs_response import ListRunsResponse  # noqa: E501
from timestep.apis.openai.models.message_object import MessageObject  # noqa: E501
from timestep.apis.openai.models.modify_assistant_request import ModifyAssistantRequest  # noqa: E501
from timestep.apis.openai.models.modify_message_request import ModifyMessageRequest  # noqa: E501
from timestep.apis.openai.models.modify_run_request import ModifyRunRequest  # noqa: E501
from timestep.apis.openai.models.modify_thread_request import ModifyThreadRequest  # noqa: E501
from timestep.apis.openai.models.run_object import RunObject  # noqa: E501
from timestep.apis.openai.models.run_step_object import RunStepObject  # noqa: E501
from timestep.apis.openai.models.submit_tool_outputs_run_request import SubmitToolOutputsRunRequest  # noqa: E501
from timestep.apis.openai.models.thread_object import ThreadObject  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestAssistantsController(BaseTestCase):
    """AssistantsController integration test stubs"""

    def test_cancel_run(self):
        """Test case for cancel_run

        Cancels a run that is `in_progress`.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs/{run_id}/cancel'.format(thread_id='thread_id_example', run_id='run_id_example'),
            method='POST',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_assistant(self):
        """Test case for create_assistant

        Create an assistant with a model and instructions.
        """
        create_assistant_request = {"top_p":1,"instructions":"instructions","tool_resources":{"code_interpreter":{"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]},"file_search":{"vector_store_ids":["vector_store_ids"],"vector_stores":[{"chunking_strategy":{"type":"auto"},"metadata":"{}","file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]}]}},"metadata":"{}","response_format":"none","name":"name","temperature":1,"description":"description","model":"gpt-4-turbo","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"}]}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/assistants',
            method='POST',
            headers=headers,
            data=json.dumps(create_assistant_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_message(self):
        """Test case for create_message

        Create a message.
        """
        create_message_request = {"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/messages'.format(thread_id='thread_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(create_message_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_run(self):
        """Test case for create_run

        Create a run.
        """
        create_run_request = {"instructions":"instructions","additional_instructions":"additional_instructions","metadata":"{}","assistant_id":"assistant_id","additional_messages":[{"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"},{"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"}],"tools":[{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"}],"truncation_strategy":{"last_messages":1,"type":"auto"},"top_p":1,"max_completion_tokens":256,"response_format":"none","parallel_tool_calls":True,"stream":True,"temperature":1,"tool_choice":"none","model":"gpt-4-turbo","max_prompt_tokens":256}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs'.format(thread_id='thread_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(create_run_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_thread(self):
        """Test case for create_thread

        Create a thread.
        """
        create_thread_request = {"tool_resources":{"code_interpreter":{"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]},"file_search":{"vector_store_ids":["vector_store_ids"],"vector_stores":[{"chunking_strategy":{"type":"auto"},"metadata":"{}","file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]}]}},"metadata":"{}","messages":[{"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"},{"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"}]}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads',
            method='POST',
            headers=headers,
            data=json.dumps(create_thread_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_thread_and_run(self):
        """Test case for create_thread_and_run

        Create a thread and run it in one request.
        """
        create_thread_and_run_request = {"instructions":"instructions","tool_resources":{"code_interpreter":{"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]},"file_search":{"vector_store_ids":["vector_store_ids"]}},"metadata":"{}","assistant_id":"assistant_id","thread":{"tool_resources":{"code_interpreter":{"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]},"file_search":{"vector_store_ids":["vector_store_ids"],"vector_stores":[{"chunking_strategy":{"type":"auto"},"metadata":"{}","file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]}]}},"metadata":"{}","messages":[{"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"},{"metadata":"{}","role":"user","attachments":[{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]},{"file_id":"file_id","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"}]}],"content":"CreateMessageRequest_content"}]},"tools":[{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"}],"truncation_strategy":{"last_messages":1,"type":"auto"},"top_p":1,"max_completion_tokens":256,"response_format":"none","parallel_tool_calls":True,"stream":True,"temperature":1,"tool_choice":"none","model":"gpt-4-turbo","max_prompt_tokens":256}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/runs',
            method='POST',
            headers=headers,
            data=json.dumps(create_thread_and_run_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_delete_assistant(self):
        """Test case for delete_assistant

        Delete an assistant.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/assistants/{assistant_id}'.format(assistant_id='assistant_id_example'),
            method='DELETE',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_delete_message(self):
        """Test case for delete_message

        Deletes a message.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/messages/{message_id}'.format(thread_id='thread_id_example', message_id='message_id_example'),
            method='DELETE',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_delete_thread(self):
        """Test case for delete_thread

        Delete a thread.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}'.format(thread_id='thread_id_example'),
            method='DELETE',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_assistant(self):
        """Test case for get_assistant

        Retrieves an assistant.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/assistants/{assistant_id}'.format(assistant_id='assistant_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_message(self):
        """Test case for get_message

        Retrieve a message.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/messages/{message_id}'.format(thread_id='thread_id_example', message_id='message_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_run(self):
        """Test case for get_run

        Retrieves a run.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs/{run_id}'.format(thread_id='thread_id_example', run_id='run_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_run_step(self):
        """Test case for get_run_step

        Retrieves a run step.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs/{run_id}/steps/{step_id}'.format(thread_id='thread_id_example', run_id='run_id_example', step_id='step_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_thread(self):
        """Test case for get_thread

        Retrieves a thread.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}'.format(thread_id='thread_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_assistants(self):
        """Test case for list_assistants

        Returns a list of assistants.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/assistants',
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_messages(self):
        """Test case for list_messages

        Returns a list of messages for a given thread.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example'),
                        ('run_id', 'run_id_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/messages'.format(thread_id='thread_id_example'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_run_steps(self):
        """Test case for list_run_steps

        Returns a list of run steps belonging to a run.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs/{run_id}/steps'.format(thread_id='thread_id_example', run_id='run_id_example'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_runs(self):
        """Test case for list_runs

        Returns a list of runs belonging to a thread.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs'.format(thread_id='thread_id_example'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_modify_assistant(self):
        """Test case for modify_assistant

        Modifies an assistant.
        """
        modify_assistant_request = {"top_p":1,"instructions":"instructions","tool_resources":{"code_interpreter":{"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]},"file_search":{"vector_store_ids":["vector_store_ids"]}},"metadata":"{}","response_format":"none","name":"name","temperature":1,"description":"description","model":"model","tools":[{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"},{"type":"code_interpreter"}]}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/assistants/{assistant_id}'.format(assistant_id='assistant_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(modify_assistant_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_modify_message(self):
        """Test case for modify_message

        Modifies a message.
        """
        modify_message_request = {"metadata":"{}"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/messages/{message_id}'.format(thread_id='thread_id_example', message_id='message_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(modify_message_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_modify_run(self):
        """Test case for modify_run

        Modifies a run.
        """
        modify_run_request = {"metadata":"{}"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs/{run_id}'.format(thread_id='thread_id_example', run_id='run_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(modify_run_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_modify_thread(self):
        """Test case for modify_thread

        Modifies a thread.
        """
        modify_thread_request = {"tool_resources":{"code_interpreter":{"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]},"file_search":{"vector_store_ids":["vector_store_ids"]}},"metadata":"{}"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}'.format(thread_id='thread_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(modify_thread_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_submit_tool_ouputs_to_run(self):
        """Test case for submit_tool_ouputs_to_run

        When a run has the `status: \"requires_action\"` and `required_action.type` is `submit_tool_outputs`, this endpoint can be used to submit the outputs from the tool calls once they're all completed. All outputs must be submitted in a single request. 
        """
        submit_tool_outputs_run_request = {"stream":True,"tool_outputs":[{"output":"output","tool_call_id":"tool_call_id"},{"output":"output","tool_call_id":"tool_call_id"}]}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/threads/{thread_id}/runs/{run_id}/submit_tool_outputs'.format(thread_id='thread_id_example', run_id='run_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(submit_tool_outputs_run_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import unittest

from flask import json

from timestep.apis.openai.models.create_embedding_request import CreateEmbeddingRequest  # noqa: E501
from timestep.apis.openai.models.create_embedding_response import CreateEmbeddingResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestEmbeddingsController(BaseTestCase):
    """EmbeddingsController integration test stubs"""

    def test_create_embedding(self):
        """Test case for create_embedding

        Creates an embedding vector representing the input text.
        """
        create_embedding_request = {"input":"The quick brown fox jumped over the lazy dog","encoding_format":"float","model":"text-embedding-3-small","user":"user-1234","dimensions":1}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/embeddings',
            method='POST',
            headers=headers,
            data=json.dumps(create_embedding_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import reflex as rx


class LoadingIcon(rx.Component):
    """A custom loading icon component."""

    library = "react-loading-icons"
    tag = "SpinningCircles"
    stroke: rx.Var[str]
    stroke_opacity: rx.Var[str]
    fill: rx.Var[str]
    fill_opacity: rx.Var[str]
    stroke_width: rx.Var[str]
    speed: rx.Var[str]
    height: rx.Var[str]

    def get_event_triggers(self) -> dict:
        return {"on_change": lambda status: [status]}


loading_icon = LoadingIcon.create



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.create_moderation_request import CreateModerationRequest  # noqa: E501
from timestep.apis.openai.models.create_moderation_response import CreateModerationResponse  # noqa: E501
from timestep.apis.openai import util


def create_moderation(create_moderation_request):  # noqa: E501
    """Classifies if text is potentially harmful.

     # noqa: E501

    :param create_moderation_request: 
    :type create_moderation_request: dict | bytes

    :rtype: Union[CreateModerationResponse, Tuple[CreateModerationResponse, int], Tuple[CreateModerationResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_moderation_request = CreateModerationRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'



"""The main Chat app."""

import reflex as rx
from timestep.components import chat, navbar


def index() -> rx.Component:
    """The main app."""
    return rx.chakra.vstack(
        navbar(),
        chat.chat(),
        chat.action_bar(),
        background_color=rx.color("mauve", 1),
        color=rx.color("mauve", 12),
        min_height="100vh",
        align_items="stretch",
        spacing="0",
    )


# Add state and page to the app.
app = rx.App(
    theme=rx.theme(
        appearance="dark",
        accent_color="violet",
    ),
)

app.add_page(index)



import asyncio
import json
import connexion
from typing import Dict, Iterator
from typing import Tuple
from typing import Union

from fastapi.responses import StreamingResponse
import flask
from llama_cpp.llama_types import CreateChatCompletionResponse, CreateChatCompletionStreamResponse
from openai import OpenAI, Stream
from openai.types.chat.chat_completion_chunk import ChatCompletionChunk
from openai.types.chat.chat_completion import ChatCompletion
from sse_starlette.sse import EventSourceResponse

# from timestep.apis.openai.models.create_chat_completion_request import CreateChatCompletionRequest  # noqa: E501
# from timestep.apis.openai.models.create_chat_completion_response import CreateChatCompletionResponse  # noqa: E501
from timestep.apis.openai import util
from timestep.services.model import llm

async def create_chat_completion(body): # req: Request
    """Creates a model response for the given chat conversation.

     # noqa: E501

    :param create_chat_completion_request: 
    :type create_chat_completion_request: dict | bytes

    :rtype: Union[CreateChatCompletionResponse, Tuple[CreateChatCompletionResponse, int], Tuple[CreateChatCompletionResponse, int, Dict[str, str]]
    """
    # if connexion.request.is_json:
    #     create_chat_completion_request = CreateChatCompletionRequest.from_dict(connexion.request.get_json())  # noqa: E501

    if body.get("stream", False) == True:
        async def event_publisher():
            response: Iterator[CreateChatCompletionStreamResponse] = llm.create_chat_completion(
                messages=body.get("messages"),
                model=body.get("model"),
                stream=body.get("stream"),
                temperature=body.get("temperature"),
            )

            try:
                for chunk in response:
                    yield json.dumps(chunk)
                    # await asyncio.sleep(0.2)

            except asyncio.CancelledError as e:
                # print(f"Disconnected from client (via refresh/close) {req.client}")
                print(f"Disconnected from client (via refresh/close)")
                # Do any other cleanup, if any
                raise e

        return EventSourceResponse(event_publisher())

    else:
        response: CreateChatCompletionResponse = llm.create_chat_completion(
            messages=body.get("messages"),
            model=body.get("model"),
            stream=body.get("stream"),
            temperature=body.get("temperature"),
        )

        return response



import os
from pathlib import Path
from typing import Any, Callable

from connexion import AsyncApp
from connexion.exceptions import OAuthProblem
from connexion.resolver import RelativeResolver, Resolver
from connexion.utils import get_function_from_name

from timestep.api import generate_token

token = generate_token(47)
print('token: ', token)

app = AsyncApp(__name__)

app.add_api(
    "apis/openai/openapi/openapi.yaml",
    base_path="/api/openai/v1",
    pythonic_params=True,
    # resolver=RelativeResolver('timestep.api'),
    resolver_error=501,
)



from llama_cpp import Llama
from llama_cpp.llama_chat_format import MoondreamChatHandler

chat_handler = MoondreamChatHandler.from_pretrained(
  repo_id="vikhyatk/moondream2",
  filename="*mmproj*",
)

llm = Llama.from_pretrained(
  repo_id="vikhyatk/moondream2",
  filename="*text-model*",
  chat_handler=chat_handler,
  n_ctx=2048, # n_ctx should be increased to accommodate the image embedding
)



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.delete_model_response import DeleteModelResponse  # noqa: E501
from timestep.apis.openai.models.list_models_response import ListModelsResponse  # noqa: E501
from timestep.apis.openai.models.model import Model  # noqa: E501
from timestep.apis.openai import util


def delete_model(model):  # noqa: E501
    """Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.

     # noqa: E501

    :param model: The model to delete
    :type model: str

    :rtype: Union[DeleteModelResponse, Tuple[DeleteModelResponse, int], Tuple[DeleteModelResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def list_models():  # noqa: E501
    """Lists the currently available models, and provides basic information about each one such as the owner and availability.

     # noqa: E501


    :rtype: Union[ListModelsResponse, Tuple[ListModelsResponse, int], Tuple[ListModelsResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def retrieve_model(model):  # noqa: E501
    """Retrieves a model instance, providing basic information about the model such as the owner and permissioning.

     # noqa: E501

    :param model: The ID of the model to use for this request
    :type model: str

    :rtype: Union[Model, Tuple[Model, int], Tuple[Model, int, Dict[str, str]]
    """
    return 'do some magic!'



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.batch import Batch  # noqa: E501
from timestep.apis.openai.models.create_batch_request import CreateBatchRequest  # noqa: E501
from timestep.apis.openai.models.list_batches_response import ListBatchesResponse  # noqa: E501
from timestep.apis.openai import util


def cancel_batch(batch_id):  # noqa: E501
    """Cancels an in-progress batch. The batch will be in status &#x60;cancelling&#x60; for up to 10 minutes, before changing to &#x60;cancelled&#x60;, where it will have partial results (if any) available in the output file.

     # noqa: E501

    :param batch_id: The ID of the batch to cancel.
    :type batch_id: str

    :rtype: Union[Batch, Tuple[Batch, int], Tuple[Batch, int, Dict[str, str]]
    """
    return 'do some magic!'


def create_batch(create_batch_request):  # noqa: E501
    """Creates and executes a batch from an uploaded file of requests

     # noqa: E501

    :param create_batch_request: 
    :type create_batch_request: dict | bytes

    :rtype: Union[Batch, Tuple[Batch, int], Tuple[Batch, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_batch_request = CreateBatchRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def list_batches(after=None, limit=None):  # noqa: E501
    """List your organization&#39;s batches.

     # noqa: E501

    :param after: A cursor for use in pagination. &#x60;after&#x60; is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after&#x3D;obj_foo in order to fetch the next page of the list. 
    :type after: str
    :param limit: A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20. 
    :type limit: int

    :rtype: Union[ListBatchesResponse, Tuple[ListBatchesResponse, int], Tuple[ListBatchesResponse, int, Dict[str, str]]
    """
    return 'do some magic!'


def retrieve_batch(batch_id):  # noqa: E501
    """Retrieves a batch.

     # noqa: E501

    :param batch_id: The ID of the batch to retrieve.
    :type batch_id: str

    :rtype: Union[Batch, Tuple[Batch, int], Tuple[Batch, int, Dict[str, str]]
    """
    return 'do some magic!'



import os
import reflex as rx
from openai import OpenAI


# Checking if the API key is set properly
# if not os.getenv("OPENAI_API_KEY"):
#     raise Exception("Please set OPENAI_API_KEY environment variable.")


class QA(rx.Base):
    """A question and answer pair."""

    question: str
    answer: str


DEFAULT_CHATS = {
    "Intros": [],
}


class State(rx.State):
    """The app state."""

    # A dict from the chat name to the list of questions and answers.
    chats: dict[str, list[QA]] = DEFAULT_CHATS

    # The current chat name.
    current_chat = "Intros"

    # The current question.
    question: str

    # Whether we are processing the question.
    processing: bool = False

    # The name of the new chat.
    new_chat_name: str = ""

    def create_chat(self):
        """Create a new chat."""
        # Add the new chat to the list of chats.
        self.current_chat = self.new_chat_name
        self.chats[self.new_chat_name] = []

    def delete_chat(self):
        """Delete the current chat."""
        del self.chats[self.current_chat]
        if len(self.chats) == 0:
            self.chats = DEFAULT_CHATS
        self.current_chat = list(self.chats.keys())[0]

    def set_chat(self, chat_name: str):
        """Set the name of the current chat.

        Args:
            chat_name: The name of the chat.
        """
        self.current_chat = chat_name

    @rx.var
    def chat_titles(self) -> list[str]:
        """Get the list of chat titles.

        Returns:
            The list of chat names.
        """
        return list(self.chats.keys())

    async def process_question(self, form_data: dict[str, str]):
        # Get the question from the form
        question = form_data["question"]

        # Check if the question is empty
        if question == "":
            return

        model = self.openai_process_question

        async for value in model(question):
            yield value

    async def openai_process_question(self, question: str):
        """Get the response from the API.

        Args:
            form_data: A dict with the current question.
        """

        # Add the question to the list of questions.
        qa = QA(question=question, answer="")
        self.chats[self.current_chat].append(qa)

        # Clear the input and start the processing.
        self.processing = True
        yield

        # Build the messages.
        messages = [
            {
                "role": "system",
                "content": "You are a friendly chatbot named Reflex. Respond in markdown.",
            }
        ]

        for qa in self.chats[self.current_chat]:
            messages.append({"role": "user", "content": qa.question})
            messages.append({"role": "assistant", "content": qa.answer})

        # Remove the last mock answer.
        messages = messages[:-1]

        host = '0.0.0.0'
        port = 8080

        api_key = "sk-no-key-required"
        base_url=f"http://{host}:{port}/v1"

        client = OpenAI(
            api_key=api_key,
            base_url=base_url,
        )

        # Start a new session to answer the question.
        session = client.chat.completions.create(
            # model=os.getenv("OPENAI_MODEL", "gpt-3.5-turbo"),
            model="LLaMA_CPP",
            messages=messages,
            stream=True,
        )

        # Stream the results, yielding after every word.
        for item in session:
            if hasattr(item.choices[0].delta, "content"):
                answer_text = item.choices[0].delta.content
                # Ensure answer_text is not None before concatenation
                if answer_text is not None:
                    self.chats[self.current_chat][-1].answer += answer_text

                else:
                    # Handle the case where answer_text is None, perhaps log it or assign a default value
                    # For example, assigning an empty string if answer_text is None
                    answer_text = ""
                    self.chats[self.current_chat][-1].answer += answer_text

                self.chats = self.chats
                yield

        # Toggle the processing flag.
        self.processing = False



import reflex as rx
from timestep.state import State


def modal() -> rx.Component:
    """A modal to create a new chat."""
    return rx.chakra.modal(
        rx.chakra.modal_overlay(
            rx.chakra.modal_content(
                rx.chakra.modal_header(
                    rx.chakra.hstack(
                        rx.chakra.text("Create new chat"),
                        rx.chakra.icon(
                            tag="close",
                            font_size="sm",
                            on_click=State.toggle_modal,
                            color="#fff8",
                            _hover={"color": "#fff"},
                            cursor="pointer",
                        ),
                        align_items="center",
                        justify_content="space-between",
                    )
                ),
                rx.chakra.modal_body(
                    rx.chakra.input(
                        placeholder="Type something...",
                        on_blur=State.set_new_chat_name,
                        bg="#222",
                        border_color="#fff3",
                        _placeholder={"color": "#fffa"},
                    ),
                ),
                rx.chakra.modal_footer(
                    rx.chakra.button(
                        "Create",
                        bg="#5535d4",
                        box_shadow="md",
                        px="4",
                        py="2",
                        h="auto",
                        _hover={"bg": "#4c2db3"},
                        on_click=State.create_chat,
                    ),
                ),
                bg="#222",
                color="#fff",
            ),
        ),
        is_open=State.modal_open,
    )



import unittest

from flask import json

from timestep.apis.openai.models.batch import Batch  # noqa: E501
from timestep.apis.openai.models.create_batch_request import CreateBatchRequest  # noqa: E501
from timestep.apis.openai.models.list_batches_response import ListBatchesResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestBatchController(BaseTestCase):
    """BatchController integration test stubs"""

    def test_cancel_batch(self):
        """Test case for cancel_batch

        Cancels an in-progress batch. The batch will be in status `cancelling` for up to 10 minutes, before changing to `cancelled`, where it will have partial results (if any) available in the output file.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/batches/{batch_id}/cancel'.format(batch_id='batch_id_example'),
            method='POST',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_batch(self):
        """Test case for create_batch

        Creates and executes a batch from an uploaded file of requests
        """
        create_batch_request = timestep.apis.openai.CreateBatchRequest()
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/batches',
            method='POST',
            headers=headers,
            data=json.dumps(create_batch_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_batches(self):
        """Test case for list_batches

        List your organization's batches.
        """
        query_string = [('after', 'after_example'),
                        ('limit', 20)]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/batches',
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_retrieve_batch(self):
        """Test case for retrieve_batch

        Retrieves a batch.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/batches/{batch_id}'.format(batch_id='batch_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import unittest

from flask import json

from timestep.apis.openai.models.create_image_edit_request_model import CreateImageEditRequestModel  # noqa: E501
from timestep.apis.openai.models.create_image_request import CreateImageRequest  # noqa: E501
from timestep.apis.openai.models.images_response import ImagesResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestImagesController(BaseTestCase):
    """ImagesController integration test stubs"""

    def test_create_image(self):
        """Test case for create_image

        Creates an image given a prompt.
        """
        create_image_request = {"response_format":"url","size":"1024x1024","model":"dall-e-3","style":"vivid","prompt":"A cute baby sea otter","user":"user-1234","n":1,"quality":"standard"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/images/generations',
            method='POST',
            headers=headers,
            data=json.dumps(create_image_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_image_edit(self):
        """Test case for create_image_edit

        Creates an edited or extended image given an original image and a prompt.
        """
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'multipart/form-data',
            'Authorization': 'Bearer special-key',
        }
        data = dict(image='/path/to/file',
                    prompt='prompt_example',
                    mask='/path/to/file',
                    model=timestep.apis.openai.CreateImageEditRequestModel(),
                    n=1,
                    size=1024x1024,
                    response_format=url,
                    user='user_example')
        response = self.client.open(
            '/v1/images/edits',
            method='POST',
            headers=headers,
            data=data,
            content_type='multipart/form-data')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_image_variation(self):
        """Test case for create_image_variation

        Creates a variation of a given image.
        """
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'multipart/form-data',
            'Authorization': 'Bearer special-key',
        }
        data = dict(image='/path/to/file',
                    model=timestep.apis.openai.CreateImageEditRequestModel(),
                    n=1,
                    response_format=url,
                    size=1024x1024,
                    user='user_example')
        response = self.client.open(
            '/v1/images/variations',
            method='POST',
            headers=headers,
            data=data,
            content_type='multipart/form-data')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



    #!/usr/bin/env python3

import os
import time

from openai import OpenAI, Stream
from openai.types.chat.chat_completion_chunk import ChatCompletionChunk
from openai.types.chat.chat_completion import ChatCompletion
import typer

import timestep.llamafile

typer_app = typer.Typer()

host = '0.0.0.0'
port = 8000


@typer_app.callback()
def callback():
    """
    Timestep AI CLI
    """


@typer_app.command()
def serve():
    """
    Serve
    """
    typer.echo("Serving...")

    raise NotImplementedError


@typer_app.command()
def test(
    # api_key = "sk-no-key-required",
    api_key: str = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJjb20uemFsYW5kby5jb25uZXhpb24iLCJpYXQiOjE3MjA3MzkwNjMsImV4cCI6MTcyMDczOTY2Mywic3ViIjoiNDcifQ.FAkQVjpop6nw6kCh0wSvtZVW3huLJdPtIq3_cCjPc6Y",
    base_url: str = f"http://{host}:{port}/api/openai/v1",
    message: str = 'Count to 10, with a comma between each number and no newlines. E.g., 1, 2, 3, ...',
    stream: bool = True,
):
    """
    Test
    """
    typer.echo("Testing...")

    client = OpenAI(
        api_key=api_key,
        base_url=base_url,
    )

    start_time = time.time()

    if stream:
        chat_completion_chunk_stream: Stream[ChatCompletionChunk] = client.chat.completions.create(
            messages=[
                {"role": "system", "content": "You an AI assistant. Your top priority is responding to user questions with truthful answers."},
                {"role": "user", "content": message},
            ],
            model="LLaMA_CPP",
            stream=True,
            stream_options={"include_usage": True}, # retrieving token usage for stream response
            temperature=0,
        )

        collected_chunks = []
        collected_messages = []

        # iterate through the stream of events
        for chunk in chat_completion_chunk_stream:
            chunk_time = time.time() - start_time  # calculate the time delay of the chunk
            collected_chunks.append(chunk)  # save the event response
            print('chunk: ', chunk)
            chunk_message = chunk.choices[0].delta.content  # extract the message
            collected_messages.append(chunk_message)  # save the message
            print(f"Message received {chunk_time:.2f} seconds after request: {chunk_message}")  # print the delay and text
            print(f"choices: {chunk.choices}\nusage: {chunk.usage}")
            print("****************")

        # print the time delay and text received
        print(f"Full response received {chunk_time:.2f} seconds after request")

        # clean None in collected_messages
        collected_messages = [m for m in collected_messages if m is not None]
        full_reply_content = ''.join(collected_messages)

    else:
        chat_completion: ChatCompletion = client.chat.completions.create(
            messages=[
                {"role": "system", "content": "You an AI assistant. Your top priority is responding to user questions with truthful answers."},
                {"role": "user", "content": message},
            ],
            model="LLaMA_CPP",
            temperature=0,
        )

        # print the time delay and text received
        print(f"Full response received {time.time() - start_time:.2f} seconds after request")

        full_reply_content = chat_completion.choices[0].message.content

    typer.echo(full_reply_content)


@typer_app.command()
def train():
    """
    Train
    """
    typer.echo("Training...")

    raise NotImplementedError


typer_app.add_typer(timestep.llamafile.typer_app, name="llamafile")



import unittest

from flask import json

from timestep.apis.openai.models.create_vector_store_file_batch_request import CreateVectorStoreFileBatchRequest  # noqa: E501
from timestep.apis.openai.models.create_vector_store_file_request import CreateVectorStoreFileRequest  # noqa: E501
from timestep.apis.openai.models.create_vector_store_request import CreateVectorStoreRequest  # noqa: E501
from timestep.apis.openai.models.delete_vector_store_file_response import DeleteVectorStoreFileResponse  # noqa: E501
from timestep.apis.openai.models.delete_vector_store_response import DeleteVectorStoreResponse  # noqa: E501
from timestep.apis.openai.models.list_vector_store_files_response import ListVectorStoreFilesResponse  # noqa: E501
from timestep.apis.openai.models.list_vector_stores_response import ListVectorStoresResponse  # noqa: E501
from timestep.apis.openai.models.update_vector_store_request import UpdateVectorStoreRequest  # noqa: E501
from timestep.apis.openai.models.vector_store_file_batch_object import VectorStoreFileBatchObject  # noqa: E501
from timestep.apis.openai.models.vector_store_file_object import VectorStoreFileObject  # noqa: E501
from timestep.apis.openai.models.vector_store_object import VectorStoreObject  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestVectorStoresController(BaseTestCase):
    """VectorStoresController integration test stubs"""

    def test_cancel_vector_store_file_batch(self):
        """Test case for cancel_vector_store_file_batch

        Cancel a vector store file batch. This attempts to cancel the processing of files in this batch as soon as possible.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/file_batches/{batch_id}/cancel'.format(vector_store_id='vector_store_id_example', batch_id='batch_id_example'),
            method='POST',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_vector_store(self):
        """Test case for create_vector_store

        Create a vector store.
        """
        create_vector_store_request = {"chunking_strategy":{"type":"auto"},"metadata":"{}","expires_after":{"anchor":"last_active_at","days":339},"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"],"name":"name"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores',
            method='POST',
            headers=headers,
            data=json.dumps(create_vector_store_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_vector_store_file(self):
        """Test case for create_vector_store_file

        Create a vector store file by attaching a [File](/docs/api-reference/files) to a [vector store](/docs/api-reference/vector-stores/object).
        """
        create_vector_store_file_request = {"chunking_strategy":{"type":"auto"},"file_id":"file_id"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/files'.format(vector_store_id='vs_abc123'),
            method='POST',
            headers=headers,
            data=json.dumps(create_vector_store_file_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_vector_store_file_batch(self):
        """Test case for create_vector_store_file_batch

        Create a vector store file batch.
        """
        create_vector_store_file_batch_request = {"chunking_strategy":{"type":"auto"},"file_ids":["file_ids","file_ids","file_ids","file_ids","file_ids"]}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/file_batches'.format(vector_store_id='vs_abc123'),
            method='POST',
            headers=headers,
            data=json.dumps(create_vector_store_file_batch_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_delete_vector_store(self):
        """Test case for delete_vector_store

        Delete a vector store.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}'.format(vector_store_id='vector_store_id_example'),
            method='DELETE',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_delete_vector_store_file(self):
        """Test case for delete_vector_store_file

        Delete a vector store file. This will remove the file from the vector store but the file itself will not be deleted. To delete the file, use the [delete file](/docs/api-reference/files/delete) endpoint.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/files/{file_id}'.format(vector_store_id='vector_store_id_example', file_id='file_id_example'),
            method='DELETE',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_vector_store(self):
        """Test case for get_vector_store

        Retrieves a vector store.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}'.format(vector_store_id='vector_store_id_example'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_vector_store_file(self):
        """Test case for get_vector_store_file

        Retrieves a vector store file.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/files/{file_id}'.format(vector_store_id='vs_abc123', file_id='file-abc123'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_get_vector_store_file_batch(self):
        """Test case for get_vector_store_file_batch

        Retrieves a vector store file batch.
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/file_batches/{batch_id}'.format(vector_store_id='vs_abc123', batch_id='vsfb_abc123'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_files_in_vector_store_batch(self):
        """Test case for list_files_in_vector_store_batch

        Returns a list of vector store files in a batch.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example'),
                        ('filter', 'filter_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/file_batches/{batch_id}/files'.format(vector_store_id='vector_store_id_example', batch_id='batch_id_example'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_vector_store_files(self):
        """Test case for list_vector_store_files

        Returns a list of vector store files.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example'),
                        ('filter', 'filter_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}/files'.format(vector_store_id='vector_store_id_example'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_vector_stores(self):
        """Test case for list_vector_stores

        Returns a list of vector stores.
        """
        query_string = [('limit', 20),
                        ('order', desc),
                        ('after', 'after_example'),
                        ('before', 'before_example')]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores',
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_modify_vector_store(self):
        """Test case for modify_vector_store

        Modifies a vector store.
        """
        update_vector_store_request = {"metadata":"{}","expires_after":{"anchor":"last_active_at","days":339},"name":"name"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/vector_stores/{vector_store_id}'.format(vector_store_id='vector_store_id_example'),
            method='POST',
            headers=headers,
            data=json.dumps(update_vector_store_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import os

import typer

from timestep.utils import download_with_progress_bar, start_shell_script, stop_shell_script

typer_app = typer.Typer()

default_llamafile_filename = "TinyLlama-1.1B-Chat-v1.0.F16.llamafile"
default_llamafile_url = f"https://huggingface.co/Mozilla/TinyLlama-1.1B-Chat-v1.0-llamafile/resolve/main/{default_llamafile_filename}?download=true"


@typer_app.command()
def load(
    llamafile_path=f"./models/{default_llamafile_filename}",
    host='0.0.0.0',
    public_path='/zip/llama.cpp/server/public',
    port=8080,
):
    """
    Load a model
    """
    typer.echo(f"Loading model...")

    if os.path.basename(llamafile_path) == default_llamafile_filename and not os.path.exists(llamafile_path):
        os.makedirs(os.path.dirname(llamafile_path))
        download_with_progress_bar(default_llamafile_url, llamafile_path)

    assert os.path.exists(llamafile_path)

    process = start_shell_script(
        llamafile_path,
        '--host', host,
        '--path', public_path,
        '--port', f'{port}',
    )

    typer.echo(f"... loaded model with PID: {process.pid}.")


@typer_app.command()
def unload(pid: int):
    """
    Unload a model by PID
    """
    typer.echo("Unloading model...")

    stop_shell_script(pid)

    typer.echo(f"... unloaded model with PID: {pid}.")


if __name__ == "__main__":
    typer_app()



import unittest

from flask import json

from timestep.apis.openai.models.create_moderation_request import CreateModerationRequest  # noqa: E501
from timestep.apis.openai.models.create_moderation_response import CreateModerationResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestModerationsController(BaseTestCase):
    """ModerationsController integration test stubs"""

    def test_create_moderation(self):
        """Test case for create_moderation

        Classifies if text is potentially harmful.
        """
        create_moderation_request = {"input":"I want to kill them.","model":"text-moderation-stable"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/moderations',
            method='POST',
            headers=headers,
            data=json.dumps(create_moderation_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import connexion
from typing import Dict
from typing import Tuple
from typing import Union

from timestep.apis.openai.models.create_image_edit_request_model import CreateImageEditRequestModel  # noqa: E501
from timestep.apis.openai.models.create_image_request import CreateImageRequest  # noqa: E501
from timestep.apis.openai.models.images_response import ImagesResponse  # noqa: E501
from timestep.apis.openai import util


def create_image(create_image_request):  # noqa: E501
    """Creates an image given a prompt.

     # noqa: E501

    :param create_image_request: 
    :type create_image_request: dict | bytes

    :rtype: Union[ImagesResponse, Tuple[ImagesResponse, int], Tuple[ImagesResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        create_image_request = CreateImageRequest.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def create_image_edit(image, prompt, mask=None, model=None, n=None, size=None, response_format=None, user=None):  # noqa: E501
    """Creates an edited or extended image given an original image and a prompt.

     # noqa: E501

    :param image: The image to edit. Must be a valid PNG file, less than 4MB, and square. If mask is not provided, image must have transparency, which will be used as the mask.
    :type image: str
    :param prompt: A text description of the desired image(s). The maximum length is 1000 characters.
    :type prompt: str
    :param mask: An additional image whose fully transparent areas (e.g. where alpha is zero) indicate where &#x60;image&#x60; should be edited. Must be a valid PNG file, less than 4MB, and have the same dimensions as &#x60;image&#x60;.
    :type mask: str
    :param model: 
    :type model: dict | bytes
    :param n: The number of images to generate. Must be between 1 and 10.
    :type n: int
    :param size: The size of the generated images. Must be one of &#x60;256x256&#x60;, &#x60;512x512&#x60;, or &#x60;1024x1024&#x60;.
    :type size: str
    :param response_format: The format in which the generated images are returned. Must be one of &#x60;url&#x60; or &#x60;b64_json&#x60;. URLs are only valid for 60 minutes after the image has been generated.
    :type response_format: str
    :param user: A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. [Learn more](/docs/guides/safety-best-practices/end-user-ids). 
    :type user: str

    :rtype: Union[ImagesResponse, Tuple[ImagesResponse, int], Tuple[ImagesResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        model = CreateImageEditRequestModel.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'


def create_image_variation(image, model=None, n=None, response_format=None, size=None, user=None):  # noqa: E501
    """Creates a variation of a given image.

     # noqa: E501

    :param image: The image to use as the basis for the variation(s). Must be a valid PNG file, less than 4MB, and square.
    :type image: str
    :param model: 
    :type model: dict | bytes
    :param n: The number of images to generate. Must be between 1 and 10. For &#x60;dall-e-3&#x60;, only &#x60;n&#x3D;1&#x60; is supported.
    :type n: int
    :param response_format: The format in which the generated images are returned. Must be one of &#x60;url&#x60; or &#x60;b64_json&#x60;. URLs are only valid for 60 minutes after the image has been generated.
    :type response_format: str
    :param size: The size of the generated images. Must be one of &#x60;256x256&#x60;, &#x60;512x512&#x60;, or &#x60;1024x1024&#x60;.
    :type size: str
    :param user: A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. [Learn more](/docs/guides/safety-best-practices/end-user-ids). 
    :type user: str

    :rtype: Union[ImagesResponse, Tuple[ImagesResponse, int], Tuple[ImagesResponse, int, Dict[str, str]]
    """
    if connexion.request.is_json:
        model = CreateImageEditRequestModel.from_dict(connexion.request.get_json())  # noqa: E501
    return 'do some magic!'



import reflex as rx

from timestep.components import loading_icon
from timestep.state import QA, State


message_style = dict(display="inline-block", padding="1em", border_radius="8px", max_width=["30em", "30em", "50em", "50em", "50em", "50em"])


def message(qa: QA) -> rx.Component:
    """A single question/answer message.

    Args:
        qa: The question/answer pair.

    Returns:
        A component displaying the question/answer pair.
    """
    return rx.box(
        rx.box(
            rx.markdown(
                qa.question,
                background_color=rx.color("mauve", 4),
                color=rx.color("mauve", 12),
                **message_style,
            ),
            text_align="right",
            margin_top="1em",
        ),
        rx.box(
            rx.markdown(
                qa.answer,
                background_color=rx.color("accent", 4),
                color=rx.color("accent", 12),
                **message_style,
            ),
            text_align="left",
            padding_top="1em",
        ),
        width="100%",
    )


def chat() -> rx.Component:
    """List all the messages in a single conversation."""
    return rx.vstack(
        rx.box(rx.foreach(State.chats[State.current_chat], message), width="100%"),
        py="8",
        flex="1",
        width="100%",
        max_width="50em",
        padding_x="4px",
        align_self="center",
        overflow="hidden",
        padding_bottom="5em",
    )


def action_bar() -> rx.Component:
    """The action bar to send a new message."""
    return rx.center(
        rx.vstack(
            rx.chakra.form(
                rx.chakra.form_control(
                    rx.hstack(
                        rx.input(
                            rx.input.slot(
                                rx.tooltip(
                                    rx.icon("info", size=18),
                                    content="Enter a question to get a response.",
                                )
                            ),
                            placeholder="Type something...",
                            id="question",
                            width=["15em", "20em", "45em", "50em", "50em", "50em"],
                        ),
                        rx.button(
                            rx.cond(
                                State.processing,
                                loading_icon(height="1em"),
                                rx.text("Send"),
                            ),
                            type="submit",
                        ),
                        align_items="center",
                    ),
                    is_disabled=State.processing,
                ),
                on_submit=State.process_question,
                reset_on_submit=True,
            ),
            rx.text(
                "ReflexGPT may return factually incorrect or misleading responses. Use discretion.",
                text_align="center",
                font_size=".75em",
                color=rx.color("mauve", 10),
            ),
            rx.logo(margin_top="-1em", margin_bottom="-1em"),
            align_items="center",
        ),
        position="sticky",
        bottom="0",
        left="0",
        padding_y="16px",
        backdrop_filter="auto",
        backdrop_blur="lg",
        border_top=f"1px solid {rx.color('mauve', 3)}",
        background_color=rx.color("mauve", 2),
        align_items="stretch",
        width="100%",
    )



import unittest

from flask import json

from timestep.apis.openai.models.create_completion_request import CreateCompletionRequest  # noqa: E501
from timestep.apis.openai.models.create_completion_response import CreateCompletionResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestCompletionsController(BaseTestCase):
    """CompletionsController integration test stubs"""

    def test_create_completion(self):
        """Test case for create_completion

        Creates a completion for the provided prompt and parameters.
        """
        create_completion_request = {"logit_bias":{"key":1},"seed":-2147483648,"max_tokens":16,"presence_penalty":0.25495066265333133,"echo":False,"suffix":"test.","n":1,"logprobs":2,"top_p":1,"frequency_penalty":0.4109824732281613,"best_of":1,"stop":"\n","stream":False,"temperature":1,"model":"CreateCompletionRequest_model","stream_options":{"include_usage":True},"prompt":"This is a test.","user":"user-1234"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/completions',
            method='POST',
            headers=headers,
            data=json.dumps(create_completion_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import unittest

from flask import json

from timestep.apis.openai.models.create_chat_completion_request import CreateChatCompletionRequest  # noqa: E501
from timestep.apis.openai.models.create_chat_completion_response import CreateChatCompletionResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestChatController(BaseTestCase):
    """ChatController integration test stubs"""

    def test_create_chat_completion(self):
        """Test case for create_chat_completion

        Creates a model response for the given chat conversation.
        """
        create_chat_completion_request = {"top_logprobs":2,"logit_bias":{"key":6},"seed":-2147483648,"functions":[{"name":"name","description":"description","parameters":{"key":""}},{"name":"name","description":"description","parameters":{"key":""}},{"name":"name","description":"description","parameters":{"key":""}},{"name":"name","description":"description","parameters":{"key":""}},{"name":"name","description":"description","parameters":{"key":""}}],"max_tokens":5,"function_call":"none","presence_penalty":0.25495066265333133,"tools":[{"function":{"name":"name","description":"description","parameters":{"key":""}},"type":"function"},{"function":{"name":"name","description":"description","parameters":{"key":""}},"type":"function"}],"n":1,"logprobs":False,"top_p":1,"frequency_penalty":-1.6796687238155954,"response_format":{"type":"json_object"},"stop":"CreateChatCompletionRequest_stop","parallel_tool_calls":True,"stream":False,"temperature":1,"messages":[{"role":"system","name":"name","content":"content"},{"role":"system","name":"name","content":"content"}],"tool_choice":"none","model":"gpt-4-turbo","service_tier":"auto","stream_options":{"include_usage":True},"user":"user-1234"}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/chat/completions',
            method='POST',
            headers=headers,
            data=json.dumps(create_chat_completion_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import unittest

from flask import json

from timestep.apis.openai.models.create_speech_request import CreateSpeechRequest  # noqa: E501
from timestep.apis.openai.models.create_transcription200_response import CreateTranscription200Response  # noqa: E501
from timestep.apis.openai.models.create_transcription_request_model import CreateTranscriptionRequestModel  # noqa: E501
from timestep.apis.openai.models.create_translation200_response import CreateTranslation200Response  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestAudioController(BaseTestCase):
    """AudioController integration test stubs"""

    def test_create_speech(self):
        """Test case for create_speech

        Generates audio from the input text.
        """
        create_speech_request = {"voice":"alloy","input":"input","response_format":"mp3","model":"CreateSpeechRequest_model","speed":0.5503105714228793}
        headers = { 
            'Accept': 'application/octet-stream',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/audio/speech',
            method='POST',
            headers=headers,
            data=json.dumps(create_speech_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_transcription(self):
        """Test case for create_transcription

        Transcribes audio into the input language.
        """
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'multipart/form-data',
            'Authorization': 'Bearer special-key',
        }
        data = dict(file='/path/to/file',
                    model=timestep.apis.openai.CreateTranscriptionRequestModel(),
                    language='language_example',
                    prompt='prompt_example',
                    response_format=json,
                    temperature=0,
                    timestamp_granularities=['timestamp_granularities_example'])
        response = self.client.open(
            '/v1/audio/transcriptions',
            method='POST',
            headers=headers,
            data=data,
            content_type='multipart/form-data')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    @unittest.skip("multipart/form-data not supported by Connexion")
    def test_create_translation(self):
        """Test case for create_translation

        Translates audio into English.
        """
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'multipart/form-data',
            'Authorization': 'Bearer special-key',
        }
        data = dict(file='/path/to/file',
                    model=timestep.apis.openai.CreateTranscriptionRequestModel(),
                    prompt='prompt_example',
                    response_format='json',
                    temperature=0)
        response = self.client.open(
            '/v1/audio/translations',
            method='POST',
            headers=headers,
            data=data,
            content_type='multipart/form-data')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import unittest

from flask import json

from timestep.apis.openai.models.create_fine_tuning_job_request import CreateFineTuningJobRequest  # noqa: E501
from timestep.apis.openai.models.fine_tuning_job import FineTuningJob  # noqa: E501
from timestep.apis.openai.models.list_fine_tuning_job_checkpoints_response import ListFineTuningJobCheckpointsResponse  # noqa: E501
from timestep.apis.openai.models.list_fine_tuning_job_events_response import ListFineTuningJobEventsResponse  # noqa: E501
from timestep.apis.openai.models.list_paginated_fine_tuning_jobs_response import ListPaginatedFineTuningJobsResponse  # noqa: E501
from timestep.apis.openai.test import BaseTestCase


class TestFineTuningController(BaseTestCase):
    """FineTuningController integration test stubs"""

    def test_cancel_fine_tuning_job(self):
        """Test case for cancel_fine_tuning_job

        Immediately cancel a fine-tune job. 
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/fine_tuning/jobs/{fine_tuning_job_id}/cancel'.format(fine_tuning_job_id='ft-AF1WoRqd3aJAHsqc9NY7iL8F'),
            method='POST',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_create_fine_tuning_job(self):
        """Test case for create_fine_tuning_job

        Creates a fine-tuning job which begins the process of creating a new model from a given dataset.  Response includes details of the enqueued job including job status and the name of the fine-tuned models once complete.  [Learn more about fine-tuning](/docs/guides/fine-tuning) 
        """
        create_fine_tuning_job_request = {"training_file":"file-abc123","seed":42,"validation_file":"file-abc123","hyperparameters":{"batch_size":"auto","n_epochs":"auto","learning_rate_multiplier":"auto"},"model":"gpt-3.5-turbo","suffix":"suffix","integrations":[{"wandb":{"name":"name","project":"my-wandb-project","entity":"entity","tags":["custom-tag","custom-tag"]},"type":"wandb"},{"wandb":{"name":"name","project":"my-wandb-project","entity":"entity","tags":["custom-tag","custom-tag"]},"type":"wandb"}]}
        headers = { 
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/fine_tuning/jobs',
            method='POST',
            headers=headers,
            data=json.dumps(create_fine_tuning_job_request),
            content_type='application/json')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_fine_tuning_events(self):
        """Test case for list_fine_tuning_events

        Get status updates for a fine-tuning job. 
        """
        query_string = [('after', 'after_example'),
                        ('limit', 20)]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/fine_tuning/jobs/{fine_tuning_job_id}/events'.format(fine_tuning_job_id='ft-AF1WoRqd3aJAHsqc9NY7iL8F'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_fine_tuning_job_checkpoints(self):
        """Test case for list_fine_tuning_job_checkpoints

        List checkpoints for a fine-tuning job. 
        """
        query_string = [('after', 'after_example'),
                        ('limit', 10)]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/fine_tuning/jobs/{fine_tuning_job_id}/checkpoints'.format(fine_tuning_job_id='ft-AF1WoRqd3aJAHsqc9NY7iL8F'),
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_list_paginated_fine_tuning_jobs(self):
        """Test case for list_paginated_fine_tuning_jobs

        List your organization's fine-tuning jobs 
        """
        query_string = [('after', 'after_example'),
                        ('limit', 20)]
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/fine_tuning/jobs',
            method='GET',
            headers=headers,
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_retrieve_fine_tuning_job(self):
        """Test case for retrieve_fine_tuning_job

        Get info about a fine-tuning job.  [Learn more about fine-tuning](/docs/guides/fine-tuning) 
        """
        headers = { 
            'Accept': 'application/json',
            'Authorization': 'Bearer special-key',
        }
        response = self.client.open(
            '/v1/fine_tuning/jobs/{fine_tuning_job_id}'.format(fine_tuning_job_id='ft-AF1WoRqd3aJAHsqc9NY7iL8F'),
            method='GET',
            headers=headers)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    unittest.main()



import sys

if sys.version_info < (3, 7):
    import typing

    def is_generic(klass):
        """ Determine whether klass is a generic class """
        return type(klass) == typing.GenericMeta

    def is_dict(klass):
        """ Determine whether klass is a Dict """
        return klass.__extra__ == dict

    def is_list(klass):
        """ Determine whether klass is a List """
        return klass.__extra__ == list

else:

    def is_generic(klass):
        """ Determine whether klass is a generic class """
        return hasattr(klass, '__origin__')

    def is_dict(klass):
        """ Determine whether klass is a Dict """
        return klass.__origin__ == dict

    def is_list(klass):
        """ Determine whether klass is a List """
        return klass.__origin__ == list



import time
from pathlib import Path

import connexion
from jose import JWTError, jwt
from werkzeug.exceptions import Unauthorized

JWT_ISSUER = "com.zalando.connexion"
JWT_SECRET = "change_this"
JWT_LIFETIME_SECONDS = 600
JWT_ALGORITHM = "HS256"


def generate_token(user_id):
    timestamp = _current_timestamp()
    payload = {
        "iss": JWT_ISSUER,
        "iat": int(timestamp),
        "exp": int(timestamp + JWT_LIFETIME_SECONDS),
        "sub": str(user_id),
    }

    return jwt.encode(payload, JWT_SECRET, algorithm=JWT_ALGORITHM)


def decode_token(token):
    try:
        return jwt.decode(token, JWT_SECRET, algorithms=[JWT_ALGORITHM])
    except JWTError as e:
        raise Unauthorized from e


def get_secret(user, token_info) -> str:
    return """
    You are user_id {user} and the secret is 'wbevuec'.
    Decoded token claims: {token_info}.
    """.format(
        user=user, token_info=token_info
    )


def _current_timestamp() -> int:
    return int(time.time())



#!/usr/bin/env python3

import connexion

from timestep.apis.openai import encoder


def main():
    app = connexion.App(__name__, specification_dir='./openapi/')
    app.app.json_encoder = encoder.JSONEncoder
    app.add_api('openapi.yaml',
                arguments={'title': 'OpenAI API'},
                pythonic_params=True)

    app.run(port=8080)


if __name__ == '__main__':
    main()
